TideHunter
===========

HTTP streaming toolbox with flow control.

[![Build Status](https://travis-ci.org/amoa/tidehunter.png?branch=master)](https://travis-ci.org/amoa/tidehunter)

## Highlights

* Stream data queue, state machine, and record counter based on Redis and redis-py.
* Based on the solid cURL and PycURL.
* OAuth supported based on python-oauth2

## Dependencies

`$ pip install oauth2 redis hiredis pycurl`

## Documentation

Coming up very soon!
